---
Author: Mike Schmitz
Tags: pkm, zettelkasten
---

Personal Knowledge Management systems (or PKMs) are all the rage lately. Collecting and connecting information from bookmarks and blog posts in a sort of "personal wiki" using tools like Roam Research and Obsidian can help you see your ideas from different perspectives. This can have big benefits not just for lifelong learners, but for anyone who is looking to do their best creative work.

But before you can really make the most of personal knowledge management apps and services, you need to understand a little bit about how they work.

## What is a Personal Knowledge Management system (PKM)?

What exactly do we mean by the term *personal knowledge management?* According to Wikipedia:

> Personal knowledge management (PKM) is a process of collecting information that a person uses to gather, classify, store, search, retrieve and share knowledge in their daily activities (Grundspenkis 2007) and the way in which these processes support work activities (Wright 2005). 

Essentially, personal knowledge management is a combination of two other concepts: Personal Information Management (PIM) and Knowledge Management (KM).

Let's consider both of these briefly.

![](https://thesweetsetup.com/wp-content/uploads/2021/02/pkmconnections.jpg)

You're probably already familiar with personal information management (PIM). This is basically the way that you get and keep information in order to help you get things done. For example, maybe you need information sent to you via email in order to complete a task for work. If you send the email to your task manager so that you have the URL to that message when you need it, that's personal information management.

![](https://thesweetsetup.com/wp-content/uploads/2021/02/thingspkmconnection.jpg)

The other concept you need to understand is *knowledge management.* This typically refers to creating or sharing knowledge and information inside of an organization. If you create standard operating procedures so that someone else can complete an organizational task, that is a form of knowledge management. It's ensuring the free flow of information, making sure that the required knowledge doesn't stay siloed and that others can access it when they need it.

Personal knowledge management combines both of these, but places an additional emphasis on sharing and creating. It's a structure for information and ideas that allows them to be connected across different domains. This results in interesting connections being made, producing new ideas and giving a big boost to the creative process - whether that is expressed through writing, music, or any other medium.

If you're not sure why you might want to connect your ideas, check out [[Connecting Notes & Bidirectional Linking]].

## 3 levels of Knowledge

What sort of knowledge are managing with a PKM anyway? Let's start by looking at the dictionary definition for knowledge:

> facts, information, and skills acquired by a person through experience or education

This is pretty broad, and could mean a lot of different things. For example, I might have a vague recollection of a statistic I read about in a book but need to do a Google search before I can I can recall what it really means. Or I might have a favorite quote that really speaks to me and I've built my personal values around it.

In my experience, there are a couple different levels of knowledge:

- **Level 1: Having something (Information)** - a lot of our digital information falls into this category. You have the ability to go find what you're looking for when you need it, but you have to first think about it before you can locate it. If you have a video course that you bought but haven't gone through yet, that would fall into this category.
- **Level 2: Understanding something (Revelation)** - this is being able to recall something without having to look it up. At this leve, you've internalized the information and are starting to make connections, but it hasn't necessarily changed how you act.
- **Level 3: Doing something (Application)** - this is where you start to see the result of the information you've collected. You don't just have it or understand it, it's changing your day-to-day actions. This is the first level where there is an actual, visible output from the information that you've collected.

Why does this matter? 

*Because there is too much information.*

FOMO (the fear of missing out) is the desire to have information from somewhere you don't currently. But as soon as you get it, you probably feel FOMO for something else - i.e. Twitter, Facebook, email, Slack, YouTube, etc. By quickly jumping from one input to the next, you feed your desire to know what's happening, but you're unable to contribute to the conversation. You need to do something with the information and ideas that you collect. Like a plant, you need to develop and nurture those ideas to see what they can really turn into.

And one of the ways to incubate those ideas is connect them to others and see what happens.

## How does a PKM help?

A good personal knowledge management system reveals connections between pieces of information. When you give your brain time and space to think, it is already *really* good at this. The problem is that it is easily overwhelmed by whatever urgent thing happens to be in front of it and it's terrible at remembering things from a long time ago.

A PKM helps overcome these genetic weaknesses by serving as an external brain. It allows you to see the connections that are already there and make new ones, which is extremely valuable when you allow yourself to incubate these ideas for a long period of time.

While the term PKM has gained immense popularity recently, it's actually nothing new. There have personal knowledge management systems in place for many years. Here's some examples:

- A Commonplace Book - basically a collection of notes, quotes, and anecdotes that you want to remember. Author Ryan Holiday has a great explanation of the commonplace book [here](https://ryanholiday.net/how-and-why-to-keep-a-commonplace-book/).
- [Mind Maps](https://thesweetsetup.com/why-mind-mapping-works/)
- [Sketchnotes](https://thesweetsetup.com/guide-sketchnoting-ipad-goodnotes/)

Some of the most prolific creators in human history have been using versions of the personal knowledge management system for hundreds of years.

Technology just allows to connect things in powerful ways that were unavailable to the creatives that came before us.

## Why You Should Give Some Thought to Your PKM

*Because you ARE creative.*

You just might have forgotten how.

It doesn't matter if you are a writer, musician, desk jockey or engineer - you have the ability to be creative.

Creativity, like everything else in life, is a system. There's an input, a process, and an output. So if you haven't been seeing much creative output, it doesn't mean you lack something in your DNA - it means you need to change your inputs or process.

I know this because I've struggled with this myself.

I used to believe the lie that I just wasn’t creative. I remember playing guitar and writing songs, then getting mad when I realized that I had unintentionally picked up a melody or chord progression from another song I heard on the radio. I used to think to myself, “what is wrong with me? Why can’t I create anything original?”

But when I read Steal Like an Artist, I understood that *nothing* completely original. When someone creates something, they are simply connecting dots in new ways. That's when I realized that if I wanted to get better at creating, I just needed to collect better dots. 

> “Your job is to collect good ideas. The more good ideas you collect, the more you can choose from to be influenced by.” - Austin Kleon

And all of a sudden, I was free. 

I didn’t have to judge my creation as inferior because it was simply the results of the dots I had collected. And when I started changing my inputs (listening to podcasts, reading books), I found it easier to synthesize those ideas and create something new.

And that, in a nutshell, is why you should use a PKM - it helps you connect ideas and makes it easier for you to do your best creative work.

## What Makes a Good PKM?

A PKM is not a single application. Rather, it's a series of apps that connect together to make it easier to disseminate ideas across multiple domains. The goal is not to have information siloed, but be able to share and link it easily.

Here are some of the key components of a good PKM:

- **Note Taking** - you need a place where you can take notes 
- **Quick Capture** - capturing an idea when you have it is important so that it doesn't get lost.
- **Visual Thinking** - this is simply a way of looking at the relationship between your ideas. One common example of this would be a mind map on a topic or a graph view in an app like Roam or Obsidian.
- **Read-It-Later** - RSS can be a source of ideas, but not if it just stays inside your RSS app. Don't overlook Read-It-Later services, and make sure you have a way to capture things you want to keep.
- **Project Management** - whether you are a "knowledge worker" or a corporate desk jockey, you need a way to turn ideas into tasks.
- **Archive** - this is simple a place to hold things when you're done with them. You probably won't need to go back into the archive very often, but it's important to be able to find something later if you need it.
- **Output** - remember, your personal knowledge management system is supposed to make it *easy* for you to create. If there isn't any output, something is broken. After you've connected your dots, you need a way to express them.

You may take quick capture notes in Drafts, manage projects in Things, make mind maps in MindNode, and do all your writing (output) in Ulysses. That is a very valid approach to personal knowledge management. 

But how do you turn your captured ideas turn into projects? Or how does your mind map in help your writing? 

## The Problem with the Filing Cabinet (The Trend Towards Zettlekasten)

When it comes to managing information, most people are familiar with the traditional *filing cabinet approach*. With the filing cabinet approach, when you have a thought to find something you know exactly where to look for it. Your folder hierarchy or tagging system may not mak sense to anyone else, but that's ok - you can recall information in a flash with a simple search command.

![](https://thesweetsetup.com/wp-content/uploads/2021/02/filingcabinet.jpg)

The problem with this approach is that you have to have the thought first before you can find the file. In other words, it is a **Think --> Find** approach. Search tools allow you to find something when you need it later, but ultimately it's not doing any good tucked away in that folder *until you think of it*.

The best PKMs borrow heavily from the Zettlekasten method made popular by German sociologist Niklas Luhmann. He was a prolific creator - in only 30 years, he published 58 books and hundreds of papers. He credits the secret to his output to an external system to think in which he termed a *zettlekasten* (German for "slip box").

His zettlekasten was exactly what it sounds like - a slip box for idea, which he kept stocked with index cards. When he read something he wanted to retain, he would write the citation on one side and make brief notes on the other side. Looking at his brief notes, he would write his ideas, comments, and thoughts on a new card in the personal section. And whenever adding a note, he’d look for connections to other notes and keep them grouped together. This allowed him to view all of his related notes and ideas at once, which inspired the creative process.

![](https://thesweetsetup.com/wp-content/uploads/2021/02/zettelkasten.jpg)

With a zettlekasten, the value is not a single great idea - it's the volume of ideas you collect and the way they bump into each other. It's basically idea soup, where you mix everything together and see what comes out.  The network is more powerful than any individual node.

Fortunately, we've come a long way since the original zettlekasten. Instead of carrying around hundreds of notecards, our computers let us connect these ideas quickly and easily and access them anywhere, anytime.

The most powerful version of this is *the backlink*. This allows you to retroactively apply links between ideas in your personal knowledge management system after they've been added. For example, you may have a master note on "Habits" that can show you all the other instances of the term *habits* in your entire PKM, and clicking on any of the links will instantly take you to those old notes and ideas.

This is different than a wiki-style link because you don't need to manually make the connection when adding the new note (Mr. Luhmann would be extremely jealous).

## Recommended Resources for Building Your PKM

When it comes to making these connection, there are many different approaches and the app you decide to use will have very opinionated preferences about how to do this. Here are a few of our favorites.

### Roam Research

Roam Research is web note taking app built for connected thought. Roam allows you to write ideas and notes in plain text using Markdown, then connect those notes and ideas together using page and block references. It's a powerful system that allows you to connect not just individual files together, but even specific sections of a document.

![](https://thesweetsetup.com/wp-content/uploads/2021/02/roamresearch.jpg)

Linking things together in Roam is both easy and powerful. There are lots of incredible ways you can use these backlinks:

- [For Journaling](https://thesweetsetup.com/how-i-use-roam-research-for-journaling/)
- [For timeblocking](https://thesweetsetup.com/how-roam-research-helps-me-time-block-my-day/)
- [For GTD-style task management](https://thesweetsetup.com/using-roam-research-for-gtd-style-task-management/)
- [For Contact Relationship Management](https://thesweetsetup.com/using-roam-research-as-a-customer-relationship-manager/)
- [For personal Bible study](https://thesweetsetup.com/how-im-using-roam-research-for-bible-study/)

You can do just about anything in Roam Research if you take the time to set it up correctly. It gives you a ton of productivity building blocks that you can use to craft your own system. It's also easy to extend the functionality of the app using custom scripts or CSS.

The big drawback to Roam for some people is that everything is cloud-based (no individual local files). You can export your Roam graph into JSON or Markdown files, but everything lives on the Roam servers. There's also no native application, for iOS or otherwise. It is purely a web app - for good or bad. It also uses a variation of Markdown that is fairly annoying, and is very expensive ($15/month or $165/year).

### Obsidian

The big competitor to Roam Research is Obsidian. Like Roam, Obsidian seeks to help you connect your thoughts and ideas using plain text and backlinks. The big difference is that while Roam is a web app, Obsidian works on top of your local text files. That's right, you don't have to upload *anything*. This makes it a great option for people who need more security for their notes than Roam is able to offer.

![](https://thesweetsetup.com/wp-content/uploads/2021/02/obsidian.jpg)

Obsidian is an electron app that runs locally on your computer, but it is blazing fast and handles local links much better than Roam does. The speed of updates of Obsidian is also pretty amazing, with new versions being released roughly every week. This pace of updates has quickly closed the gap with Roam, and the third-party plugin framework makes it easy to extend Obsidian in a bunch of really useful ways.

Obsidian is also completely free. If you want to sync your data between devices using end-to-end encryption, you can purchase that as an add-on for $4/month. There's also an add-on which makes publishing text in Obsidian to a website easier for $8/month. Even with both of these add-ons though, it's still less than Roam Research and a great option for your PKM.

### Craft

Craft is an interesting app that isn't really a direct comparison to either Roam or Obsidian. It's essentially a document manager, but offers beautiful native apps for macOS, iPadOS, and iOS. 

![](https://thesweetsetup.com/wp-content/uploads/2021/02/craftconnection.jpg)

They also recently added backlinks which gives you the structure you need to use it for personal knowledge management, and they recently announced Craft Connect which allows you to send and receive info from a handful of our favorite apps. Here the are apps that are currently supported [according to the Craft website](https://www.craft.do/whats-new):

- Drafts
- Things
- OmniFocus
- iA Writer
- Ulysses
- Bear
- Day One
- NotePlan

While it's still fairly new, Craft shows a lot of promise. You can check out Josh's impression of Craft [here](https://thesweetsetup.com/using-craft-notes-for-study-and-preserving-long-term-knowledge/).

### Hook

Hook is more of a utility than an application, but it can still very handy when building your own personal knowledge management system. It lets you to quickly grab a link to whatever you happen to be looking at on your computer that you can then use to get back there whenever you need to. 

![](https://thesweetsetup.com/wp-content/uploads/2021/02/hook.jpg)

The beauty of Hook is that it allows you to connect just about anything to just about anything. Doesn't matter if it's a task in your task manager, an email in your inbox, or a local PDF on your Mac - just pop up Hook and you can easily grab a link to whatever you need. You can also use Markdown formatting for these links, which makes it perfect for pasting into plain text in an app like Roam or Obsidian.

## Some Tips for Building Your Personal Knowledge Management System

Regardless of the apps you decide to use, here are a few things to keep in mind as you are building out your PKM.

### Curate Your Collection

One of the mistakes that is easy to make at the beginning is to connect *everything*. But not every idea you have or new piece of information you come across is worth a note in your PKM. To really make the most of your network of ideas, you need to curate them by keeping the relevant information and discarding the stuff that won't be useful.  Figuring out the difference can take some time, but it's worthwhile to figure this out. 

### Supplement Your Workflow

Don't change everything simply because you want to try a shiny new app. If you've used Evernote as a collection point for years and have hundreds of notebooks full of information, moving everything to another app is a significant time investment. Look to streamlining your information workflow so that the apps you already use can communicate together better.

### Consider Your Sources

As we mentioned earlier, there's too much information to try and keep up with it all. So figure out which sources are worth paying precious attention to.  By limiting the number of blogs you follow or websites you read on a regular basis, you can make more of the new information you do receive. By decreasing the quantity, the quality naturally increases.